## Spetro

[![PyPI](https://img.shields.io/pypi/v/spetro.svg)](https://pypi.org/project/spetro/)
![Development Status](https://img.shields.io/badge/Development--Status-beta-yellow)
[![api](https://img.shields.io/badge/API--Reference-API-purple)](docs/api.md)
[![Downloads](https://pepy.tech/badge/spetro)](https://pepy.tech/project/spetro)
[![<Workflow Name>](https://github.com/aycsi/spetro/actions/workflows/publish.yml/badge.svg)](https://github.com/aycsi/spetro/actions/workflows/publish.yml)


### installation

```bash
pip install spetro
```

